@@ -89,14 +89,16 @@ class Distribution(object):
     def after_install(self):
         for pkg in self._packages:
             setup = pkg.setup
-            for filename, config in setup.config_all:
+            for cmd in setup._commands:
+                fa.sudo(cmd)
+            for filename, config in setup.config_all.iteritems():
                 sio = StringIO(config._contents.decode('utf-8'))
                 fa.put(sio, filename, use_sudo=True)
-                for cmd in config._cmd._commands:
+                for cmd in config._commands:
+                    fa.sudo(cmd)
+            if setup.after:
+                for cmd in self.get_after_commands(setup.after):
                     fa.sudo(cmd)
-        if setup.after:
-            for cmd in self.get_after_commands(setup.after):
-                fa.sudo(cmd)
 
     def get_after_commands(self, after):
         """Get an command of after an install
@@ -167,7 +169,6 @@ class Distribution(object):
                     % self.CONFIG_DIR)
         configfile = os.path.join(self.CONFIG_DIR, self.name,
                 '%s.py' % pkg)
-        print configfile
         if not os.path.isfile(configfile):
             raise NoSuchFileError(u"no such configuration file `%s`" %
                     configfile)
